diff --git a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/cumulus_pallet_xcmp_queue.rs b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/cumulus_pallet_xcmp_queue.rs
index a1a6c309aefcdc986324ef6e647591fc923e9419..0d2d16818bb0419f244eca4d72d6b5bb6019288a 100644
--- a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/cumulus_pallet_xcmp_queue.rs
+++ b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/cumulus_pallet_xcmp_queue.rs
@@ -17,8 +17,8 @@
 //! Autogenerated weights for `cumulus_pallet_xcmp_queue`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2022-07-11, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
-//! HOSTNAME: `bm4`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
+//! DATE: 2022-12-05, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! HOSTNAME: `bm6`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
 //! EXECUTION: Some(Wasm), WASM-EXECUTION: Compiled, CHAIN: Some("collectives-polkadot-dev"), DB CACHE: 1024
 
 // Executed Command:
@@ -34,7 +34,7 @@
 // --repeat=20
 // --json
 // --header=./file_header.txt
-// --output=./parachains/runtimes/collectives/collectives-polkadot/src/weights
+// --output=./parachains/runtimes/collectives/collectives-polkadot/src/weights/cumulus_pallet_xcmp_queue.rs
 
 #![cfg_attr(rustfmt, rustfmt_skip)]
 #![allow(unused_parens)]
@@ -48,13 +48,15 @@ pub struct WeightInfo<T>(PhantomData<T>);
 impl<T: frame_system::Config> cumulus_pallet_xcmp_queue::WeightInfo for WeightInfo<T> {
 	// Storage: XcmpQueue QueueConfig (r:1 w:1)
 	fn set_config_with_u32() -> Weight {
-		Weight::from_ref_time(5_294_000 as u64)
+		// Minimum execution time: 7_970 nanoseconds.
+		Weight::from_ref_time(8_227_000 as u64)
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
 	// Storage: XcmpQueue QueueConfig (r:1 w:1)
 	fn set_config_with_weight() -> Weight {
-		Weight::from_ref_time(5_180_000 as u64)
+		// Minimum execution time: 7_993 nanoseconds.
+		Weight::from_ref_time(8_212_000 as u64)
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
diff --git a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_multisig.rs b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_multisig.rs
index e24b7defc859ea118f02bccf94d91955d636e28f..947b6a2f6f9c470a02be13febe540f82323e6da5 100644
--- a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_multisig.rs
+++ b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_multisig.rs
@@ -17,8 +17,8 @@
 //! Autogenerated weights for `pallet_multisig`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2022-11-10, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
-//! HOSTNAME: `bm4`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
+//! DATE: 2022-12-05, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! HOSTNAME: `bm6`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
 //! EXECUTION: Some(Wasm), WASM-EXECUTION: Compiled, CHAIN: Some("collectives-polkadot-dev"), DB CACHE: 1024
 
 // Executed Command:
@@ -48,22 +48,22 @@ pub struct WeightInfo<T>(PhantomData<T>);
 impl<T: frame_system::Config> pallet_multisig::WeightInfo for WeightInfo<T> {
 	/// The range of component `z` is `[0, 10000]`.
 	fn as_multi_threshold_1(z: u32, ) -> Weight {
-		// Minimum execution time: 21_375 nanoseconds.
-		Weight::from_ref_time(22_118_304 as u64)
-			// Standard Error: 3
-			.saturating_add(Weight::from_ref_time(584 as u64).saturating_mul(z as u64))
+		// Minimum execution time: 21_348 nanoseconds.
+		Weight::from_ref_time(22_020_918 as u64)
+			// Standard Error: 17
+			.saturating_add(Weight::from_ref_time(793 as u64).saturating_mul(z as u64))
 	}
 	// Storage: Multisig Multisigs (r:1 w:1)
 	// Storage: unknown [0x3a65787472696e7369635f696e646578] (r:1 w:0)
 	/// The range of component `s` is `[2, 100]`.
 	/// The range of component `z` is `[0, 10000]`.
 	fn as_multi_create(s: u32, z: u32, ) -> Weight {
-		// Minimum execution time: 53_482 nanoseconds.
-		Weight::from_ref_time(41_399_699 as u64)
-			// Standard Error: 959
-			.saturating_add(Weight::from_ref_time(133_568 as u64).saturating_mul(s as u64))
-			// Standard Error: 9
-			.saturating_add(Weight::from_ref_time(1_527 as u64).saturating_mul(z as u64))
+		// Minimum execution time: 52_745 nanoseconds.
+		Weight::from_ref_time(39_633_213 as u64)
+			// Standard Error: 812
+			.saturating_add(Weight::from_ref_time(138_830 as u64).saturating_mul(s as u64))
+			// Standard Error: 7
+			.saturating_add(Weight::from_ref_time(1_774 as u64).saturating_mul(z as u64))
 			.saturating_add(T::DbWeight::get().reads(2 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
@@ -71,12 +71,12 @@ impl<T: frame_system::Config> pallet_multisig::WeightInfo for WeightInfo<T> {
 	/// The range of component `s` is `[3, 100]`.
 	/// The range of component `z` is `[0, 10000]`.
 	fn as_multi_approve(s: u32, z: u32, ) -> Weight {
-		// Minimum execution time: 40_666 nanoseconds.
-		Weight::from_ref_time(30_384_195 as u64)
-			// Standard Error: 1_027
-			.saturating_add(Weight::from_ref_time(127_961 as u64).saturating_mul(s as u64))
-			// Standard Error: 10
-			.saturating_add(Weight::from_ref_time(1_572 as u64).saturating_mul(z as u64))
+		// Minimum execution time: 42_062 nanoseconds.
+		Weight::from_ref_time(29_606_791 as u64)
+			// Standard Error: 624
+			.saturating_add(Weight::from_ref_time(133_807 as u64).saturating_mul(s as u64))
+			// Standard Error: 6
+			.saturating_add(Weight::from_ref_time(1_742 as u64).saturating_mul(z as u64))
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
@@ -85,12 +85,12 @@ impl<T: frame_system::Config> pallet_multisig::WeightInfo for WeightInfo<T> {
 	/// The range of component `s` is `[2, 100]`.
 	/// The range of component `z` is `[0, 10000]`.
 	fn as_multi_complete(s: u32, z: u32, ) -> Weight {
-		// Minimum execution time: 56_337 nanoseconds.
-		Weight::from_ref_time(44_163_779 as u64)
-			// Standard Error: 1_031
-			.saturating_add(Weight::from_ref_time(150_104 as u64).saturating_mul(s as u64))
-			// Standard Error: 10
-			.saturating_add(Weight::from_ref_time(1_568 as u64).saturating_mul(z as u64))
+		// Minimum execution time: 56_590 nanoseconds.
+		Weight::from_ref_time(43_141_831 as u64)
+			// Standard Error: 942
+			.saturating_add(Weight::from_ref_time(156_014 as u64).saturating_mul(s as u64))
+			// Standard Error: 9
+			.saturating_add(Weight::from_ref_time(1_753 as u64).saturating_mul(z as u64))
 			.saturating_add(T::DbWeight::get().reads(2 as u64))
 			.saturating_add(T::DbWeight::get().writes(2 as u64))
 	}
@@ -98,30 +98,30 @@ impl<T: frame_system::Config> pallet_multisig::WeightInfo for WeightInfo<T> {
 	// Storage: unknown [0x3a65787472696e7369635f696e646578] (r:1 w:0)
 	/// The range of component `s` is `[2, 100]`.
 	fn approve_as_multi_create(s: u32, ) -> Weight {
-		// Minimum execution time: 36_552 nanoseconds.
-		Weight::from_ref_time(39_678_753 as u64)
-			// Standard Error: 972
-			.saturating_add(Weight::from_ref_time(137_305 as u64).saturating_mul(s as u64))
+		// Minimum execution time: 35_945 nanoseconds.
+		Weight::from_ref_time(38_593_664 as u64)
+			// Standard Error: 1_135
+			.saturating_add(Weight::from_ref_time(137_421 as u64).saturating_mul(s as u64))
 			.saturating_add(T::DbWeight::get().reads(2 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
 	// Storage: Multisig Multisigs (r:1 w:1)
 	/// The range of component `s` is `[2, 100]`.
 	fn approve_as_multi_approve(s: u32, ) -> Weight {
-		// Minimum execution time: 27_419 nanoseconds.
-		Weight::from_ref_time(29_059_332 as u64)
-			// Standard Error: 753
-			.saturating_add(Weight::from_ref_time(131_180 as u64).saturating_mul(s as u64))
+		// Minimum execution time: 26_498 nanoseconds.
+		Weight::from_ref_time(28_101_368 as u64)
+			// Standard Error: 757
+			.saturating_add(Weight::from_ref_time(133_752 as u64).saturating_mul(s as u64))
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
 	// Storage: Multisig Multisigs (r:1 w:1)
 	/// The range of component `s` is `[2, 100]`.
 	fn cancel_as_multi(s: u32, ) -> Weight {
-		// Minimum execution time: 37_335 nanoseconds.
-		Weight::from_ref_time(39_940_097 as u64)
-			// Standard Error: 1_233
-			.saturating_add(Weight::from_ref_time(139_766 as u64).saturating_mul(s as u64))
+		// Minimum execution time: 36_332 nanoseconds.
+		Weight::from_ref_time(38_627_585 as u64)
+			// Standard Error: 962
+			.saturating_add(Weight::from_ref_time(142_123 as u64).saturating_mul(s as u64))
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
diff --git a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_proxy.rs b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_proxy.rs
index 8b5ad6014804fd8d1342c45f9549d9514bd9c472..8a920daa4cf0cfaac801ddc0a07d59a9f92de4fb 100644
--- a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_proxy.rs
+++ b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_proxy.rs
@@ -17,8 +17,8 @@
 //! Autogenerated weights for `pallet_proxy`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2022-11-10, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
-//! HOSTNAME: `bm4`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
+//! DATE: 2022-12-05, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! HOSTNAME: `bm6`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
 //! EXECUTION: Some(Wasm), WASM-EXECUTION: Compiled, CHAIN: Some("collectives-polkadot-dev"), DB CACHE: 1024
 
 // Executed Command:
@@ -49,10 +49,10 @@ impl<T: frame_system::Config> pallet_proxy::WeightInfo for WeightInfo<T> {
 	// Storage: Proxy Proxies (r:1 w:0)
 	/// The range of component `p` is `[1, 31]`.
 	fn proxy(p: u32, ) -> Weight {
-		// Minimum execution time: 23_916 nanoseconds.
-		Weight::from_ref_time(25_298_186 as u64)
-			// Standard Error: 1_962
-			.saturating_add(Weight::from_ref_time(56_777 as u64).saturating_mul(p as u64))
+		// Minimum execution time: 24_139 nanoseconds.
+		Weight::from_ref_time(25_454_618 as u64)
+			// Standard Error: 2_037
+			.saturating_add(Weight::from_ref_time(47_727 as u64).saturating_mul(p as u64))
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 	}
 	// Storage: Proxy Proxies (r:1 w:0)
@@ -61,12 +61,12 @@ impl<T: frame_system::Config> pallet_proxy::WeightInfo for WeightInfo<T> {
 	/// The range of component `a` is `[0, 31]`.
 	/// The range of component `p` is `[1, 31]`.
 	fn proxy_announced(a: u32, p: u32, ) -> Weight {
-		// Minimum execution time: 45_550 nanoseconds.
-		Weight::from_ref_time(45_001_780 as u64)
-			// Standard Error: 1_797
-			.saturating_add(Weight::from_ref_time(129_179 as u64).saturating_mul(a as u64))
-			// Standard Error: 1_857
-			.saturating_add(Weight::from_ref_time(61_524 as u64).saturating_mul(p as u64))
+		// Minimum execution time: 45_486 nanoseconds.
+		Weight::from_ref_time(46_085_343 as u64)
+			// Standard Error: 2_917
+			.saturating_add(Weight::from_ref_time(135_318 as u64).saturating_mul(a as u64))
+			// Standard Error: 3_014
+			.saturating_add(Weight::from_ref_time(26_445 as u64).saturating_mul(p as u64))
 			.saturating_add(T::DbWeight::get().reads(3 as u64))
 			.saturating_add(T::DbWeight::get().writes(2 as u64))
 	}
@@ -75,12 +75,12 @@ impl<T: frame_system::Config> pallet_proxy::WeightInfo for WeightInfo<T> {
 	/// The range of component `a` is `[0, 31]`.
 	/// The range of component `p` is `[1, 31]`.
 	fn remove_announcement(a: u32, p: u32, ) -> Weight {
-		// Minimum execution time: 30_911 nanoseconds.
-		Weight::from_ref_time(32_105_074 as u64)
-			// Standard Error: 1_675
-			.saturating_add(Weight::from_ref_time(133_673 as u64).saturating_mul(a as u64))
-			// Standard Error: 1_730
-			.saturating_add(Weight::from_ref_time(8_634 as u64).saturating_mul(p as u64))
+		// Minimum execution time: 30_889 nanoseconds.
+		Weight::from_ref_time(31_350_942 as u64)
+			// Standard Error: 1_248
+			.saturating_add(Weight::from_ref_time(149_414 as u64).saturating_mul(a as u64))
+			// Standard Error: 1_289
+			.saturating_add(Weight::from_ref_time(20_716 as u64).saturating_mul(p as u64))
 			.saturating_add(T::DbWeight::get().reads(2 as u64))
 			.saturating_add(T::DbWeight::get().writes(2 as u64))
 	}
@@ -89,12 +89,12 @@ impl<T: frame_system::Config> pallet_proxy::WeightInfo for WeightInfo<T> {
 	/// The range of component `a` is `[0, 31]`.
 	/// The range of component `p` is `[1, 31]`.
 	fn reject_announcement(a: u32, p: u32, ) -> Weight {
-		// Minimum execution time: 31_191 nanoseconds.
-		Weight::from_ref_time(31_504_964 as u64)
-			// Standard Error: 1_327
-			.saturating_add(Weight::from_ref_time(138_900 as u64).saturating_mul(a as u64))
-			// Standard Error: 1_371
-			.saturating_add(Weight::from_ref_time(25_702 as u64).saturating_mul(p as u64))
+		// Minimum execution time: 30_728 nanoseconds.
+		Weight::from_ref_time(31_941_234 as u64)
+			// Standard Error: 1_339
+			.saturating_add(Weight::from_ref_time(128_109 as u64).saturating_mul(a as u64))
+			// Standard Error: 1_384
+			.saturating_add(Weight::from_ref_time(16_158 as u64).saturating_mul(p as u64))
 			.saturating_add(T::DbWeight::get().reads(2 as u64))
 			.saturating_add(T::DbWeight::get().writes(2 as u64))
 	}
@@ -104,42 +104,42 @@ impl<T: frame_system::Config> pallet_proxy::WeightInfo for WeightInfo<T> {
 	/// The range of component `a` is `[0, 31]`.
 	/// The range of component `p` is `[1, 31]`.
 	fn announce(a: u32, p: u32, ) -> Weight {
-		// Minimum execution time: 40_563 nanoseconds.
-		Weight::from_ref_time(40_977_387 as u64)
-			// Standard Error: 1_852
-			.saturating_add(Weight::from_ref_time(127_040 as u64).saturating_mul(a as u64))
-			// Standard Error: 1_914
-			.saturating_add(Weight::from_ref_time(69_759 as u64).saturating_mul(p as u64))
+		// Minimum execution time: 40_662 nanoseconds.
+		Weight::from_ref_time(40_934_458 as u64)
+			// Standard Error: 1_630
+			.saturating_add(Weight::from_ref_time(137_201 as u64).saturating_mul(a as u64))
+			// Standard Error: 1_684
+			.saturating_add(Weight::from_ref_time(61_535 as u64).saturating_mul(p as u64))
 			.saturating_add(T::DbWeight::get().reads(3 as u64))
 			.saturating_add(T::DbWeight::get().writes(2 as u64))
 	}
 	// Storage: Proxy Proxies (r:1 w:1)
 	/// The range of component `p` is `[1, 31]`.
 	fn add_proxy(p: u32, ) -> Weight {
-		// Minimum execution time: 33_574 nanoseconds.
-		Weight::from_ref_time(34_501_973 as u64)
-			// Standard Error: 2_447
-			.saturating_add(Weight::from_ref_time(70_006 as u64).saturating_mul(p as u64))
+		// Minimum execution time: 33_354 nanoseconds.
+		Weight::from_ref_time(34_467_676 as u64)
+			// Standard Error: 2_111
+			.saturating_add(Weight::from_ref_time(78_774 as u64).saturating_mul(p as u64))
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
 	// Storage: Proxy Proxies (r:1 w:1)
 	/// The range of component `p` is `[1, 31]`.
 	fn remove_proxy(p: u32, ) -> Weight {
-		// Minimum execution time: 32_661 nanoseconds.
-		Weight::from_ref_time(34_427_585 as u64)
-			// Standard Error: 2_414
-			.saturating_add(Weight::from_ref_time(94_991 as u64).saturating_mul(p as u64))
+		// Minimum execution time: 32_974 nanoseconds.
+		Weight::from_ref_time(34_444_856 as u64)
+			// Standard Error: 2_324
+			.saturating_add(Weight::from_ref_time(92_503 as u64).saturating_mul(p as u64))
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
 	// Storage: Proxy Proxies (r:1 w:1)
 	/// The range of component `p` is `[1, 31]`.
 	fn remove_proxies(p: u32, ) -> Weight {
-		// Minimum execution time: 28_650 nanoseconds.
-		Weight::from_ref_time(29_749_222 as u64)
-			// Standard Error: 1_766
-			.saturating_add(Weight::from_ref_time(46_612 as u64).saturating_mul(p as u64))
+		// Minimum execution time: 28_571 nanoseconds.
+		Weight::from_ref_time(29_613_619 as u64)
+			// Standard Error: 1_648
+			.saturating_add(Weight::from_ref_time(44_494 as u64).saturating_mul(p as u64))
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
@@ -147,20 +147,20 @@ impl<T: frame_system::Config> pallet_proxy::WeightInfo for WeightInfo<T> {
 	// Storage: Proxy Proxies (r:1 w:1)
 	/// The range of component `p` is `[1, 31]`.
 	fn create_pure(p: u32, ) -> Weight {
-		// Minimum execution time: 35_910 nanoseconds.
-		Weight::from_ref_time(37_454_353 as u64)
-			// Standard Error: 1_783
-			.saturating_add(Weight::from_ref_time(493 as u64).saturating_mul(p as u64))
+		// Minimum execution time: 36_090 nanoseconds.
+		Weight::from_ref_time(37_328_149 as u64)
+			// Standard Error: 1_617
+			.saturating_add(Weight::from_ref_time(7_522 as u64).saturating_mul(p as u64))
 			.saturating_add(T::DbWeight::get().reads(2 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
 	// Storage: Proxy Proxies (r:1 w:1)
 	/// The range of component `p` is `[0, 30]`.
 	fn kill_pure(p: u32, ) -> Weight {
-		// Minimum execution time: 29_942 nanoseconds.
-		Weight::from_ref_time(31_390_903 as u64)
-			// Standard Error: 1_992
-			.saturating_add(Weight::from_ref_time(42_745 as u64).saturating_mul(p as u64))
+		// Minimum execution time: 29_949 nanoseconds.
+		Weight::from_ref_time(31_073_757 as u64)
+			// Standard Error: 1_429
+			.saturating_add(Weight::from_ref_time(40_550 as u64).saturating_mul(p as u64))
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
diff --git a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_session.rs b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_session.rs
index f30514db0673dd13ac0de6792d3429ab35428265..d07ff00c0640bbe7ee908c151afb762e3e351eee 100644
--- a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_session.rs
+++ b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_session.rs
@@ -17,8 +17,8 @@
 //! Autogenerated weights for `pallet_session`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2022-11-10, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
-//! HOSTNAME: `bm4`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
+//! DATE: 2022-12-05, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! HOSTNAME: `bm6`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
 //! EXECUTION: Some(Wasm), WASM-EXECUTION: Compiled, CHAIN: Some("collectives-polkadot-dev"), DB CACHE: 1024
 
 // Executed Command:
@@ -49,16 +49,16 @@ impl<T: frame_system::Config> pallet_session::WeightInfo for WeightInfo<T> {
 	// Storage: Session NextKeys (r:1 w:1)
 	// Storage: Session KeyOwner (r:1 w:1)
 	fn set_keys() -> Weight {
-		// Minimum execution time: 24_755 nanoseconds.
-		Weight::from_ref_time(25_389_000 as u64)
+		// Minimum execution time: 24_240 nanoseconds.
+		Weight::from_ref_time(24_699_000 as u64)
 			.saturating_add(T::DbWeight::get().reads(2 as u64))
 			.saturating_add(T::DbWeight::get().writes(2 as u64))
 	}
 	// Storage: Session NextKeys (r:1 w:1)
 	// Storage: Session KeyOwner (r:0 w:1)
 	fn purge_keys() -> Weight {
-		// Minimum execution time: 20_645 nanoseconds.
-		Weight::from_ref_time(21_233_000 as u64)
+		// Minimum execution time: 20_812 nanoseconds.
+		Weight::from_ref_time(21_204_000 as u64)
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(2 as u64))
 	}
diff --git a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/frame_system.rs b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/frame_system.rs
index 38bc1fc1f1f71d0f99d04f93c0e8b039989a8b33..5f267c7723f2fc3ac02c9e492bcf3571ab26cf9a 100644
--- a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/frame_system.rs
+++ b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/frame_system.rs
@@ -17,8 +17,8 @@
 //! Autogenerated weights for `frame_system`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2022-11-10, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
-//! HOSTNAME: `bm4`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
+//! DATE: 2022-12-05, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! HOSTNAME: `bm6`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
 //! EXECUTION: Some(Wasm), WASM-EXECUTION: Compiled, CHAIN: Some("collectives-polkadot-dev"), DB CACHE: 1024
 
 // Executed Command:
@@ -48,51 +48,51 @@ pub struct WeightInfo<T>(PhantomData<T>);
 impl<T: frame_system::Config> frame_system::WeightInfo for WeightInfo<T> {
 	/// The range of component `b` is `[0, 3932160]`.
 	fn remark(b: u32, ) -> Weight {
-		// Minimum execution time: 3_986 nanoseconds.
-		Weight::from_ref_time(4_150_000 as u64)
+		// Minimum execution time: 4_351 nanoseconds.
+		Weight::from_ref_time(4_403_000 as u64)
 			// Standard Error: 0
-			.saturating_add(Weight::from_ref_time(411 as u64).saturating_mul(b as u64))
+			.saturating_add(Weight::from_ref_time(511 as u64).saturating_mul(b as u64))
 	}
 	/// The range of component `b` is `[0, 3932160]`.
 	fn remark_with_event(b: u32, ) -> Weight {
-		// Minimum execution time: 13_573 nanoseconds.
-		Weight::from_ref_time(13_750_000 as u64)
+		// Minimum execution time: 14_431 nanoseconds.
+		Weight::from_ref_time(14_820_000 as u64)
 			// Standard Error: 0
-			.saturating_add(Weight::from_ref_time(1_495 as u64).saturating_mul(b as u64))
+			.saturating_add(Weight::from_ref_time(1_595 as u64).saturating_mul(b as u64))
 	}
 	// Storage: System Digest (r:1 w:1)
 	// Storage: unknown [0x3a686561707061676573] (r:0 w:1)
 	fn set_heap_pages() -> Weight {
-		// Minimum execution time: 8_715 nanoseconds.
-		Weight::from_ref_time(9_111_000 as u64)
+		// Minimum execution time: 8_894 nanoseconds.
+		Weight::from_ref_time(9_170_000 as u64)
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(2 as u64))
 	}
 	// Storage: Skipped Metadata (r:0 w:0)
 	/// The range of component `i` is `[0, 1000]`.
 	fn set_storage(i: u32, ) -> Weight {
-		// Minimum execution time: 4_152 nanoseconds.
-		Weight::from_ref_time(4_243_000 as u64)
-			// Standard Error: 813
-			.saturating_add(Weight::from_ref_time(642_493 as u64).saturating_mul(i as u64))
+		// Minimum execution time: 4_363 nanoseconds.
+		Weight::from_ref_time(4_411_000 as u64)
+			// Standard Error: 793
+			.saturating_add(Weight::from_ref_time(650_122 as u64).saturating_mul(i as u64))
 			.saturating_add(T::DbWeight::get().writes((1 as u64).saturating_mul(i as u64)))
 	}
 	// Storage: Skipped Metadata (r:0 w:0)
 	/// The range of component `i` is `[0, 1000]`.
 	fn kill_storage(i: u32, ) -> Weight {
-		// Minimum execution time: 4_182 nanoseconds.
-		Weight::from_ref_time(4_325_000 as u64)
-			// Standard Error: 1_070
-			.saturating_add(Weight::from_ref_time(557_187 as u64).saturating_mul(i as u64))
+		// Minimum execution time: 4_224 nanoseconds.
+		Weight::from_ref_time(4_335_000 as u64)
+			// Standard Error: 1_002
+			.saturating_add(Weight::from_ref_time(560_274 as u64).saturating_mul(i as u64))
 			.saturating_add(T::DbWeight::get().writes((1 as u64).saturating_mul(i as u64)))
 	}
 	// Storage: Skipped Metadata (r:0 w:0)
 	/// The range of component `p` is `[0, 1000]`.
 	fn kill_prefix(p: u32, ) -> Weight {
-		// Minimum execution time: 5_669 nanoseconds.
-		Weight::from_ref_time(5_722_000 as u64)
-			// Standard Error: 1_384
-			.saturating_add(Weight::from_ref_time(1_165_138 as u64).saturating_mul(p as u64))
+		// Minimum execution time: 5_682 nanoseconds.
+		Weight::from_ref_time(5_829_000 as u64)
+			// Standard Error: 1_186
+			.saturating_add(Weight::from_ref_time(1_171_722 as u64).saturating_mul(p as u64))
 			.saturating_add(T::DbWeight::get().writes((1 as u64).saturating_mul(p as u64)))
 	}
 }
diff --git a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_alliance.rs b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_alliance.rs
index 7fd0afd5d4231e0d63ded02693110d00e27c8a23..9bdb6828e3d7e245a784fb3e13b4cec48fd6803d 100644
--- a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_alliance.rs
+++ b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_alliance.rs
@@ -17,23 +17,22 @@
 //! Autogenerated weights for `pallet_alliance`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2022-11-10, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
-//! HOSTNAME: `bm4`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
+//! DATE: 2022-12-05, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! HOSTNAME: `bm6`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
 //! EXECUTION: Some(Wasm), WASM-EXECUTION: Compiled, CHAIN: Some("collectives-polkadot-dev"), DB CACHE: 1024
 
 // Executed Command:
-// /home/benchbot/cargo_target_dir/production/polkadot-parachain
+// ./artifacts/polkadot-parachain
 // benchmark
 // pallet
-// --steps=50
-// --repeat=20
-// --extrinsic=*
+// --chain=collectives-polkadot-dev
 // --execution=wasm
 // --wasm-execution=compiled
-// --heap-pages=4096
-// --json-file=/var/lib/gitlab-runner/builds/zyw4fam_/0/parity/mirrors/cumulus/.git/.artifacts/bench.json
 // --pallet=pallet_alliance
-// --chain=collectives-polkadot-dev
+// --extrinsic=*
+// --steps=50
+// --repeat=20
+// --json
 // --header=./file_header.txt
 // --output=./parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_alliance.rs
 
@@ -189,15 +188,15 @@ impl<T: frame_system::Config> pallet_alliance::WeightInfo for WeightInfo<T> {
 	/// The range of component `y` is `[0, 100]`.
 	/// The range of component `z` is `[0, 50]`.
 	fn disband(x: u32, y: u32, z: u32, ) -> Weight {
-		// Minimum execution time: 145_000 nanoseconds.
-		Weight::from_ref_time(147_000_000 as u64)
-			// Standard Error: 13_290
-			.saturating_add(Weight::from_ref_time(304_371 as u64).saturating_mul(x as u64))
-			// Standard Error: 13_226
-			.saturating_add(Weight::from_ref_time(330_798 as u64).saturating_mul(y as u64))
-			// Standard Error: 26_428
-			.saturating_add(Weight::from_ref_time(7_207_748 as u64).saturating_mul(z as u64))
-			.saturating_add(T::DbWeight::get().reads(3 as u64))
+		// Minimum execution time: 249_184 nanoseconds.
+		Weight::from_ref_time(250_681_000 as u64)
+			// Standard Error: 19_667
+			.saturating_add(Weight::from_ref_time(455_603 as u64).saturating_mul(x as u64))
+			// Standard Error: 19_572
+			.saturating_add(Weight::from_ref_time(495_179 as u64).saturating_mul(y as u64))
+			// Standard Error: 39_109
+			.saturating_add(Weight::from_ref_time(9_510_054 as u64).saturating_mul(z as u64))
+			.saturating_add(T::DbWeight::get().reads(4 as u64))
 			.saturating_add(T::DbWeight::get().reads((1 as u64).saturating_mul(x as u64)))
 			.saturating_add(T::DbWeight::get().reads((1 as u64).saturating_mul(y as u64)))
 			.saturating_add(T::DbWeight::get().reads((1 as u64).saturating_mul(z as u64)))
@@ -206,21 +205,21 @@ impl<T: frame_system::Config> pallet_alliance::WeightInfo for WeightInfo<T> {
 	}
 	// Storage: Alliance Rule (r:0 w:1)
 	fn set_rule() -> Weight {
-		// Minimum execution time: 11_000 nanoseconds.
-		Weight::from_ref_time(12_000_000 as u64)
+		// Minimum execution time: 19_428 nanoseconds.
+		Weight::from_ref_time(19_751_000 as u64)
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
 	// Storage: Alliance Announcements (r:1 w:1)
 	fn announce() -> Weight {
-		// Minimum execution time: 13_000 nanoseconds.
-		Weight::from_ref_time(14_000_000 as u64)
+		// Minimum execution time: 21_318 nanoseconds.
+		Weight::from_ref_time(21_687_000 as u64)
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
 	// Storage: Alliance Announcements (r:1 w:1)
 	fn remove_announcement() -> Weight {
-		// Minimum execution time: 14_000 nanoseconds.
-		Weight::from_ref_time(14_000_000 as u64)
+		// Minimum execution time: 23_694 nanoseconds.
+		Weight::from_ref_time(24_344_000 as u64)
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
@@ -229,17 +228,17 @@ impl<T: frame_system::Config> pallet_alliance::WeightInfo for WeightInfo<T> {
 	// Storage: System Account (r:1 w:1)
 	// Storage: Alliance DepositOf (r:0 w:1)
 	fn join_alliance() -> Weight {
-		// Minimum execution time: 39_000 nanoseconds.
-		Weight::from_ref_time(41_000_000 as u64)
-			.saturating_add(T::DbWeight::get().reads(5 as u64))
+		// Minimum execution time: 56_749 nanoseconds.
+		Weight::from_ref_time(57_576_000 as u64)
+			.saturating_add(T::DbWeight::get().reads(6 as u64))
 			.saturating_add(T::DbWeight::get().writes(3 as u64))
 	}
 	// Storage: Alliance Members (r:3 w:1)
 	// Storage: Alliance UnscrupulousAccounts (r:1 w:0)
 	fn nominate_ally() -> Weight {
-		// Minimum execution time: 29_000 nanoseconds.
-		Weight::from_ref_time(30_000_000 as u64)
-			.saturating_add(T::DbWeight::get().reads(4 as u64))
+		// Minimum execution time: 42_096 nanoseconds.
+		Weight::from_ref_time(43_313_000 as u64)
+			.saturating_add(T::DbWeight::get().reads(5 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
 	// Storage: Alliance Members (r:2 w:2)
@@ -247,9 +246,9 @@ impl<T: frame_system::Config> pallet_alliance::WeightInfo for WeightInfo<T> {
 	// Storage: AllianceMotion Members (r:0 w:1)
 	// Storage: AllianceMotion Prime (r:0 w:1)
 	fn elevate_ally() -> Weight {
-		// Minimum execution time: 23_000 nanoseconds.
-		Weight::from_ref_time(24_000_000 as u64)
-			.saturating_add(T::DbWeight::get().reads(3 as u64))
+		// Minimum execution time: 38_364 nanoseconds.
+		Weight::from_ref_time(38_849_000 as u64)
+			.saturating_add(T::DbWeight::get().reads(4 as u64))
 			.saturating_add(T::DbWeight::get().writes(4 as u64))
 	}
 	// Storage: Alliance Members (r:4 w:2)
@@ -258,8 +257,8 @@ impl<T: frame_system::Config> pallet_alliance::WeightInfo for WeightInfo<T> {
 	// Storage: AllianceMotion Prime (r:0 w:1)
 	// Storage: Alliance RetiringMembers (r:0 w:1)
 	fn give_retirement_notice() -> Weight {
-		// Minimum execution time: 31_000 nanoseconds.
-		Weight::from_ref_time(32_000_000 as u64)
+		// Minimum execution time: 40_735 nanoseconds.
+		Weight::from_ref_time(42_445_000 as u64)
 			.saturating_add(T::DbWeight::get().reads(5 as u64))
 			.saturating_add(T::DbWeight::get().writes(5 as u64))
 	}
@@ -268,8 +267,8 @@ impl<T: frame_system::Config> pallet_alliance::WeightInfo for WeightInfo<T> {
 	// Storage: Alliance DepositOf (r:1 w:1)
 	// Storage: System Account (r:1 w:1)
 	fn retire() -> Weight {
-		// Minimum execution time: 29_000 nanoseconds.
-		Weight::from_ref_time(30_000_000 as u64)
+		// Minimum execution time: 45_591 nanoseconds.
+		Weight::from_ref_time(46_041_000 as u64)
 			.saturating_add(T::DbWeight::get().reads(4 as u64))
 			.saturating_add(T::DbWeight::get().writes(4 as u64))
 	}
@@ -280,22 +279,22 @@ impl<T: frame_system::Config> pallet_alliance::WeightInfo for WeightInfo<T> {
 	// Storage: AllianceMotion Members (r:0 w:1)
 	// Storage: AllianceMotion Prime (r:0 w:1)
 	fn kick_member() -> Weight {
-		// Minimum execution time: 45_000 nanoseconds.
-		Weight::from_ref_time(47_000_000 as u64)
-			.saturating_add(T::DbWeight::get().reads(6 as u64))
-			.saturating_add(T::DbWeight::get().writes(5 as u64))
+		// Minimum execution time: 127_782 nanoseconds.
+		Weight::from_ref_time(129_150_000 as u64)
+			.saturating_add(T::DbWeight::get().reads(13 as u64))
+			.saturating_add(T::DbWeight::get().writes(8 as u64))
 	}
 	// Storage: Alliance UnscrupulousAccounts (r:1 w:1)
 	// Storage: Alliance UnscrupulousWebsites (r:1 w:1)
 	/// The range of component `n` is `[0, 100]`.
 	/// The range of component `l` is `[0, 255]`.
 	fn add_unscrupulous_items(n: u32, l: u32, ) -> Weight {
-		// Minimum execution time: 9_000 nanoseconds.
-		Weight::from_ref_time(9_512_816 as u64)
-			// Standard Error: 2_976
-			.saturating_add(Weight::from_ref_time(560_175 as u64).saturating_mul(n as u64))
-			// Standard Error: 1_169
-			.saturating_add(Weight::from_ref_time(24_530 as u64).saturating_mul(l as u64))
+		// Minimum execution time: 17_614 nanoseconds.
+		Weight::from_ref_time(17_734_000 as u64)
+			// Standard Error: 3_794
+			.saturating_add(Weight::from_ref_time(1_353_109 as u64).saturating_mul(n as u64))
+			// Standard Error: 1_486
+			.saturating_add(Weight::from_ref_time(81_145 as u64).saturating_mul(l as u64))
 			.saturating_add(T::DbWeight::get().reads(2 as u64))
 			.saturating_add(T::DbWeight::get().writes(2 as u64))
 	}
@@ -303,11 +302,13 @@ impl<T: frame_system::Config> pallet_alliance::WeightInfo for WeightInfo<T> {
 	// Storage: Alliance UnscrupulousWebsites (r:1 w:1)
 	/// The range of component `n` is `[0, 100]`.
 	/// The range of component `l` is `[0, 255]`.
-	fn remove_unscrupulous_items(n: u32, _l: u32, ) -> Weight {
-		// Minimum execution time: 10_000 nanoseconds.
-		Weight::from_ref_time(10_000_000 as u64)
-			// Standard Error: 94_049
-			.saturating_add(Weight::from_ref_time(10_887_604 as u64).saturating_mul(n as u64))
+	fn remove_unscrupulous_items(n: u32, l: u32, ) -> Weight {
+		// Minimum execution time: 17_483 nanoseconds.
+		Weight::from_ref_time(17_695_000 as u64)
+			// Standard Error: 212_194
+			.saturating_add(Weight::from_ref_time(14_853_347 as u64).saturating_mul(n as u64))
+			// Standard Error: 83_104
+			.saturating_add(Weight::from_ref_time(740_176 as u64).saturating_mul(l as u64))
 			.saturating_add(T::DbWeight::get().reads(2 as u64))
 			.saturating_add(T::DbWeight::get().writes(2 as u64))
 	}
diff --git a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_balances.rs b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_balances.rs
index 1b642ed47d603828bd20c5d53043475cbbcc36ae..3bd5a1ce6b27fffbc60cf71a8164a3398a05ba4c 100644
--- a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_balances.rs
+++ b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_balances.rs
@@ -17,8 +17,8 @@
 //! Autogenerated weights for `pallet_balances`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2022-11-10, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
-//! HOSTNAME: `bm4`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
+//! DATE: 2022-12-05, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! HOSTNAME: `bm6`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
 //! EXECUTION: Some(Wasm), WASM-EXECUTION: Compiled, CHAIN: Some("collectives-polkadot-dev"), DB CACHE: 1024
 
 // Executed Command:
@@ -48,50 +48,50 @@ pub struct WeightInfo<T>(PhantomData<T>);
 impl<T: frame_system::Config> pallet_balances::WeightInfo for WeightInfo<T> {
 	// Storage: System Account (r:1 w:1)
 	fn transfer() -> Weight {
-		// Minimum execution time: 47_430 nanoseconds.
-		Weight::from_ref_time(48_117_000 as u64)
+		// Minimum execution time: 48_654 nanoseconds.
+		Weight::from_ref_time(49_181_000 as u64)
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
 	// Storage: System Account (r:1 w:1)
 	fn transfer_keep_alive() -> Weight {
-		// Minimum execution time: 35_634 nanoseconds.
-		Weight::from_ref_time(36_363_000 as u64)
+		// Minimum execution time: 36_282 nanoseconds.
+		Weight::from_ref_time(36_834_000 as u64)
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
 	// Storage: System Account (r:1 w:1)
 	fn set_balance_creating() -> Weight {
-		// Minimum execution time: 26_905 nanoseconds.
-		Weight::from_ref_time(27_293_000 as u64)
+		// Minimum execution time: 26_460 nanoseconds.
+		Weight::from_ref_time(26_834_000 as u64)
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
 	// Storage: System Account (r:1 w:1)
 	fn set_balance_killing() -> Weight {
-		// Minimum execution time: 30_211 nanoseconds.
-		Weight::from_ref_time(30_724_000 as u64)
+		// Minimum execution time: 30_330 nanoseconds.
+		Weight::from_ref_time(30_961_000 as u64)
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
 	// Storage: System Account (r:2 w:2)
 	fn force_transfer() -> Weight {
-		// Minimum execution time: 47_361 nanoseconds.
-		Weight::from_ref_time(47_881_000 as u64)
+		// Minimum execution time: 48_735 nanoseconds.
+		Weight::from_ref_time(49_328_000 as u64)
 			.saturating_add(T::DbWeight::get().reads(2 as u64))
 			.saturating_add(T::DbWeight::get().writes(2 as u64))
 	}
 	// Storage: System Account (r:1 w:1)
 	fn transfer_all() -> Weight {
-		// Minimum execution time: 41_548 nanoseconds.
-		Weight::from_ref_time(42_436_000 as u64)
+		// Minimum execution time: 41_999 nanoseconds.
+		Weight::from_ref_time(42_891_000 as u64)
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
 	// Storage: System Account (r:1 w:1)
 	fn force_unreserve() -> Weight {
-		// Minimum execution time: 22_925 nanoseconds.
-		Weight::from_ref_time(23_318_000 as u64)
+		// Minimum execution time: 22_834 nanoseconds.
+		Weight::from_ref_time(23_430_000 as u64)
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
diff --git a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_collator_selection.rs b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_collator_selection.rs
index 60fd36ff70e190a8fd710891105cbd9e67980d36..5c22a040926c0f9d29a6f2c34a8fc3e71215b201 100644
--- a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_collator_selection.rs
+++ b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_collator_selection.rs
@@ -17,8 +17,8 @@
 //! Autogenerated weights for `pallet_collator_selection`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2022-11-10, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
-//! HOSTNAME: `bm4`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
+//! DATE: 2022-12-05, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! HOSTNAME: `bm6`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
 //! EXECUTION: Some(Wasm), WASM-EXECUTION: Compiled, CHAIN: Some("collectives-polkadot-dev"), DB CACHE: 1024
 
 // Executed Command:
@@ -50,23 +50,23 @@ impl<T: frame_system::Config> pallet_collator_selection::WeightInfo for WeightIn
 	// Storage: CollatorSelection Invulnerables (r:0 w:1)
 	/// The range of component `b` is `[1, 100]`.
 	fn set_invulnerables(b: u32, ) -> Weight {
-		// Minimum execution time: 23_322 nanoseconds.
-		Weight::from_ref_time(24_348_106 as u64)
-			// Standard Error: 3_151
-			.saturating_add(Weight::from_ref_time(2_541_981 as u64).saturating_mul(b as u64))
+		// Minimum execution time: 24_296 nanoseconds.
+		Weight::from_ref_time(25_121_114 as u64)
+			// Standard Error: 4_734
+			.saturating_add(Weight::from_ref_time(2_497_065 as u64).saturating_mul(b as u64))
 			.saturating_add(T::DbWeight::get().reads((1 as u64).saturating_mul(b as u64)))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
 	// Storage: CollatorSelection DesiredCandidates (r:0 w:1)
 	fn set_desired_candidates() -> Weight {
-		// Minimum execution time: 14_089 nanoseconds.
-		Weight::from_ref_time(14_453_000 as u64)
+		// Minimum execution time: 14_753 nanoseconds.
+		Weight::from_ref_time(15_065_000 as u64)
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
 	// Storage: CollatorSelection CandidacyBond (r:0 w:1)
 	fn set_candidacy_bond() -> Weight {
-		// Minimum execution time: 14_560 nanoseconds.
-		Weight::from_ref_time(14_887_000 as u64)
+		// Minimum execution time: 14_928 nanoseconds.
+		Weight::from_ref_time(15_321_000 as u64)
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
 	// Storage: CollatorSelection Candidates (r:1 w:1)
@@ -77,10 +77,10 @@ impl<T: frame_system::Config> pallet_collator_selection::WeightInfo for WeightIn
 	// Storage: CollatorSelection LastAuthoredBlock (r:0 w:1)
 	/// The range of component `c` is `[1, 999]`.
 	fn register_as_candidate(c: u32, ) -> Weight {
-		// Minimum execution time: 50_116 nanoseconds.
-		Weight::from_ref_time(64_624_914 as u64)
-			// Standard Error: 883
-			.saturating_add(Weight::from_ref_time(167_758 as u64).saturating_mul(c as u64))
+		// Minimum execution time: 50_764 nanoseconds.
+		Weight::from_ref_time(64_931_732 as u64)
+			// Standard Error: 980
+			.saturating_add(Weight::from_ref_time(180_232 as u64).saturating_mul(c as u64))
 			.saturating_add(T::DbWeight::get().reads(5 as u64))
 			.saturating_add(T::DbWeight::get().writes(2 as u64))
 	}
@@ -88,10 +88,10 @@ impl<T: frame_system::Config> pallet_collator_selection::WeightInfo for WeightIn
 	// Storage: CollatorSelection LastAuthoredBlock (r:0 w:1)
 	/// The range of component `c` is `[6, 1000]`.
 	fn leave_intent(c: u32, ) -> Weight {
-		// Minimum execution time: 39_267 nanoseconds.
-		Weight::from_ref_time(65_255_254 as u64)
-			// Standard Error: 1_596
-			.saturating_add(Weight::from_ref_time(154_305 as u64).saturating_mul(c as u64))
+		// Minimum execution time: 39_924 nanoseconds.
+		Weight::from_ref_time(66_403_413 as u64)
+			// Standard Error: 1_725
+			.saturating_add(Weight::from_ref_time(163_802 as u64).saturating_mul(c as u64))
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(2 as u64))
 	}
@@ -99,8 +99,8 @@ impl<T: frame_system::Config> pallet_collator_selection::WeightInfo for WeightIn
 	// Storage: System BlockWeight (r:1 w:1)
 	// Storage: CollatorSelection LastAuthoredBlock (r:0 w:1)
 	fn note_author() -> Weight {
-		// Minimum execution time: 34_247 nanoseconds.
-		Weight::from_ref_time(34_780_000 as u64)
+		// Minimum execution time: 35_499 nanoseconds.
+		Weight::from_ref_time(35_948_000 as u64)
 			.saturating_add(T::DbWeight::get().reads(3 as u64))
 			.saturating_add(T::DbWeight::get().writes(4 as u64))
 	}
@@ -112,10 +112,10 @@ impl<T: frame_system::Config> pallet_collator_selection::WeightInfo for WeightIn
 	/// The range of component `r` is `[1, 1000]`.
 	/// The range of component `c` is `[1, 1000]`.
 	fn new_session(_r: u32, c: u32, ) -> Weight {
-		// Minimum execution time: 23_505 nanoseconds.
-		Weight::from_ref_time(23_716_000 as u64)
-			// Standard Error: 654_150
-			.saturating_add(Weight::from_ref_time(22_632_829 as u64).saturating_mul(c as u64))
+		// Minimum execution time: 23_332 nanoseconds.
+		Weight::from_ref_time(23_767_000 as u64)
+			// Standard Error: 680_100
+			.saturating_add(Weight::from_ref_time(23_752_974 as u64).saturating_mul(c as u64))
 			.saturating_add(T::DbWeight::get().reads(4 as u64))
 			.saturating_add(T::DbWeight::get().reads((1 as u64).saturating_mul(c as u64)))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
diff --git a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_collective.rs b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_collective.rs
index 056953e90a66ba0499e87d2123800661590ec774..c04ea37d09ba6cc149311ef9fdf808981b2f41a6 100644
--- a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_collective.rs
+++ b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_collective.rs
@@ -17,25 +17,24 @@
 //! Autogenerated weights for `pallet_collective`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2022-11-05, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
-//! HOSTNAME: `bm3`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
+//! DATE: 2022-12-05, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! HOSTNAME: `bm6`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
 //! EXECUTION: Some(Wasm), WASM-EXECUTION: Compiled, CHAIN: Some("collectives-polkadot-dev"), DB CACHE: 1024
 
 // Executed Command:
-// /home/benchbot/cargo_target_dir/production/polkadot-parachain
+// ./artifacts/polkadot-parachain
 // benchmark
 // pallet
-// --steps=50
-// --repeat=20
-// --extrinsic=*
+// --chain=collectives-polkadot-dev
 // --execution=wasm
 // --wasm-execution=compiled
-// --heap-pages=4096
-// --json-file=/var/lib/gitlab-runner/builds/zyw4fam_/0/parity/mirrors/cumulus/.git/.artifacts/bench.json
 // --pallet=pallet_collective
-// --chain=collectives-polkadot-dev
+// --extrinsic=*
+// --steps=50
+// --repeat=20
+// --json
 // --header=./file_header.txt
-// --output=./parachains/runtimes/collectives/collectives-polkadot/src/weights/
+// --output=./parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_collective.rs
 
 #![cfg_attr(rustfmt, rustfmt_skip)]
 #![allow(unused_parens)]
@@ -55,12 +54,12 @@ impl<T: frame_system::Config> pallet_collective::WeightInfo for WeightInfo<T> {
 	/// The range of component `n` is `[0, 100]`.
 	/// The range of component `p` is `[0, 100]`.
 	fn set_members(m: u32, _n: u32, p: u32, ) -> Weight {
-		// Minimum execution time: 17_673 nanoseconds.
-		Weight::from_ref_time(17_891_000 as u64)
-			// Standard Error: 61_591
-			.saturating_add(Weight::from_ref_time(4_893_341 as u64).saturating_mul(m as u64))
-			// Standard Error: 61_591
-			.saturating_add(Weight::from_ref_time(7_372_897 as u64).saturating_mul(p as u64))
+		// Minimum execution time: 20_020 nanoseconds.
+		Weight::from_ref_time(20_243_000 as u64)
+			// Standard Error: 64_886
+			.saturating_add(Weight::from_ref_time(5_203_566 as u64).saturating_mul(m as u64))
+			// Standard Error: 64_886
+			.saturating_add(Weight::from_ref_time(7_724_672 as u64).saturating_mul(p as u64))
 			.saturating_add(T::DbWeight::get().reads(2 as u64))
 			.saturating_add(T::DbWeight::get().reads((1 as u64).saturating_mul(p as u64)))
 			.saturating_add(T::DbWeight::get().writes(2 as u64))
@@ -70,12 +69,12 @@ impl<T: frame_system::Config> pallet_collective::WeightInfo for WeightInfo<T> {
 	/// The range of component `b` is `[1, 1024]`.
 	/// The range of component `m` is `[1, 100]`.
 	fn execute(b: u32, m: u32, ) -> Weight {
-		// Minimum execution time: 22_238 nanoseconds.
-		Weight::from_ref_time(21_508_595 as u64)
-			// Standard Error: 34
-			.saturating_add(Weight::from_ref_time(1_793 as u64).saturating_mul(b as u64))
-			// Standard Error: 360
-			.saturating_add(Weight::from_ref_time(17_737 as u64).saturating_mul(m as u64))
+		// Minimum execution time: 24_663 nanoseconds.
+		Weight::from_ref_time(23_740_074 as u64)
+			// Standard Error: 41
+			.saturating_add(Weight::from_ref_time(2_074 as u64).saturating_mul(b as u64))
+			// Standard Error: 430
+			.saturating_add(Weight::from_ref_time(19_672 as u64).saturating_mul(m as u64))
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 	}
 	// Storage: AllianceMotion Members (r:1 w:0)
@@ -83,12 +82,12 @@ impl<T: frame_system::Config> pallet_collective::WeightInfo for WeightInfo<T> {
 	/// The range of component `b` is `[1, 1024]`.
 	/// The range of component `m` is `[1, 100]`.
 	fn propose_execute(b: u32, m: u32, ) -> Weight {
-		// Minimum execution time: 24_826 nanoseconds.
-		Weight::from_ref_time(23_742_099 as u64)
-			// Standard Error: 34
-			.saturating_add(Weight::from_ref_time(1_922 as u64).saturating_mul(b as u64))
-			// Standard Error: 355
-			.saturating_add(Weight::from_ref_time(30_647 as u64).saturating_mul(m as u64))
+		// Minimum execution time: 27_356 nanoseconds.
+		Weight::from_ref_time(26_292_620 as u64)
+			// Standard Error: 47
+			.saturating_add(Weight::from_ref_time(1_993 as u64).saturating_mul(b as u64))
+			// Standard Error: 494
+			.saturating_add(Weight::from_ref_time(27_913 as u64).saturating_mul(m as u64))
 			.saturating_add(T::DbWeight::get().reads(2 as u64))
 	}
 	// Storage: AllianceMotion Members (r:1 w:0)
@@ -100,14 +99,14 @@ impl<T: frame_system::Config> pallet_collective::WeightInfo for WeightInfo<T> {
 	/// The range of component `m` is `[2, 100]`.
 	/// The range of component `p` is `[1, 100]`.
 	fn propose_proposed(b: u32, m: u32, p: u32, ) -> Weight {
-		// Minimum execution time: 31_785 nanoseconds.
-		Weight::from_ref_time(30_339_101 as u64)
-			// Standard Error: 143
-			.saturating_add(Weight::from_ref_time(4_127 as u64).saturating_mul(b as u64))
-			// Standard Error: 1_497
-			.saturating_add(Weight::from_ref_time(26_901 as u64).saturating_mul(m as u64))
-			// Standard Error: 1_478
-			.saturating_add(Weight::from_ref_time(179_739 as u64).saturating_mul(p as u64))
+		// Minimum execution time: 34_601 nanoseconds.
+		Weight::from_ref_time(31_018_653 as u64)
+			// Standard Error: 127
+			.saturating_add(Weight::from_ref_time(6_066 as u64).saturating_mul(b as u64))
+			// Standard Error: 1_328
+			.saturating_add(Weight::from_ref_time(27_417 as u64).saturating_mul(m as u64))
+			// Standard Error: 1_312
+			.saturating_add(Weight::from_ref_time(194_944 as u64).saturating_mul(p as u64))
 			.saturating_add(T::DbWeight::get().reads(4 as u64))
 			.saturating_add(T::DbWeight::get().writes(4 as u64))
 	}
@@ -115,10 +114,10 @@ impl<T: frame_system::Config> pallet_collective::WeightInfo for WeightInfo<T> {
 	// Storage: AllianceMotion Voting (r:1 w:1)
 	/// The range of component `m` is `[5, 100]`.
 	fn vote(m: u32, ) -> Weight {
-		// Minimum execution time: 33_393 nanoseconds.
-		Weight::from_ref_time(36_717_049 as u64)
-			// Standard Error: 2_427
-			.saturating_add(Weight::from_ref_time(52_572 as u64).saturating_mul(m as u64))
+		// Minimum execution time: 35_483 nanoseconds.
+		Weight::from_ref_time(38_628_067 as u64)
+			// Standard Error: 2_889
+			.saturating_add(Weight::from_ref_time(74_863 as u64).saturating_mul(m as u64))
 			.saturating_add(T::DbWeight::get().reads(2 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
@@ -129,12 +128,12 @@ impl<T: frame_system::Config> pallet_collective::WeightInfo for WeightInfo<T> {
 	/// The range of component `m` is `[4, 100]`.
 	/// The range of component `p` is `[1, 100]`.
 	fn close_early_disapproved(m: u32, p: u32, ) -> Weight {
-		// Minimum execution time: 33_378 nanoseconds.
-		Weight::from_ref_time(34_734_755 as u64)
-			// Standard Error: 1_644
-			.saturating_add(Weight::from_ref_time(28_090 as u64).saturating_mul(m as u64))
-			// Standard Error: 1_603
-			.saturating_add(Weight::from_ref_time(163_809 as u64).saturating_mul(p as u64))
+		// Minimum execution time: 36_440 nanoseconds.
+		Weight::from_ref_time(40_424_479 as u64)
+			// Standard Error: 2_324
+			.saturating_add(Weight::from_ref_time(9_789 as u64).saturating_mul(m as u64))
+			// Standard Error: 2_266
+			.saturating_add(Weight::from_ref_time(147_219 as u64).saturating_mul(p as u64))
 			.saturating_add(T::DbWeight::get().reads(3 as u64))
 			.saturating_add(T::DbWeight::get().writes(3 as u64))
 	}
@@ -146,14 +145,14 @@ impl<T: frame_system::Config> pallet_collective::WeightInfo for WeightInfo<T> {
 	/// The range of component `m` is `[4, 100]`.
 	/// The range of component `p` is `[1, 100]`.
 	fn close_early_approved(b: u32, m: u32, p: u32, ) -> Weight {
-		// Minimum execution time: 45_128 nanoseconds.
-		Weight::from_ref_time(42_122_418 as u64)
-			// Standard Error: 142
-			.saturating_add(Weight::from_ref_time(3_356 as u64).saturating_mul(b as u64))
-			// Standard Error: 1_510
-			.saturating_add(Weight::from_ref_time(42_981 as u64).saturating_mul(m as u64))
-			// Standard Error: 1_472
-			.saturating_add(Weight::from_ref_time(179_794 as u64).saturating_mul(p as u64))
+		// Minimum execution time: 48_555 nanoseconds.
+		Weight::from_ref_time(46_468_609 as u64)
+			// Standard Error: 136
+			.saturating_add(Weight::from_ref_time(2_655 as u64).saturating_mul(b as u64))
+			// Standard Error: 1_448
+			.saturating_add(Weight::from_ref_time(42_243 as u64).saturating_mul(m as u64))
+			// Standard Error: 1_412
+			.saturating_add(Weight::from_ref_time(184_606 as u64).saturating_mul(p as u64))
 			.saturating_add(T::DbWeight::get().reads(4 as u64))
 			.saturating_add(T::DbWeight::get().writes(3 as u64))
 	}
@@ -165,12 +164,12 @@ impl<T: frame_system::Config> pallet_collective::WeightInfo for WeightInfo<T> {
 	/// The range of component `m` is `[4, 100]`.
 	/// The range of component `p` is `[1, 100]`.
 	fn close_disapproved(m: u32, p: u32, ) -> Weight {
-		// Minimum execution time: 35_611 nanoseconds.
-		Weight::from_ref_time(36_011_285 as u64)
-			// Standard Error: 1_739
-			.saturating_add(Weight::from_ref_time(37_018 as u64).saturating_mul(m as u64))
-			// Standard Error: 1_696
-			.saturating_add(Weight::from_ref_time(165_311 as u64).saturating_mul(p as u64))
+		// Minimum execution time: 38_157 nanoseconds.
+		Weight::from_ref_time(39_875_224 as u64)
+			// Standard Error: 1_662
+			.saturating_add(Weight::from_ref_time(31_313 as u64).saturating_mul(m as u64))
+			// Standard Error: 1_621
+			.saturating_add(Weight::from_ref_time(168_754 as u64).saturating_mul(p as u64))
 			.saturating_add(T::DbWeight::get().reads(4 as u64))
 			.saturating_add(T::DbWeight::get().writes(3 as u64))
 	}
@@ -183,14 +182,14 @@ impl<T: frame_system::Config> pallet_collective::WeightInfo for WeightInfo<T> {
 	/// The range of component `m` is `[4, 100]`.
 	/// The range of component `p` is `[1, 100]`.
 	fn close_approved(b: u32, m: u32, p: u32, ) -> Weight {
-		// Minimum execution time: 48_279 nanoseconds.
-		Weight::from_ref_time(45_846_962 as u64)
-			// Standard Error: 148
-			.saturating_add(Weight::from_ref_time(1_953 as u64).saturating_mul(b as u64))
-			// Standard Error: 1_569
-			.saturating_add(Weight::from_ref_time(45_331 as u64).saturating_mul(m as u64))
-			// Standard Error: 1_530
-			.saturating_add(Weight::from_ref_time(181_458 as u64).saturating_mul(p as u64))
+		// Minimum execution time: 50_534 nanoseconds.
+		Weight::from_ref_time(47_567_256 as u64)
+			// Standard Error: 141
+			.saturating_add(Weight::from_ref_time(2_276 as u64).saturating_mul(b as u64))
+			// Standard Error: 1_497
+			.saturating_add(Weight::from_ref_time(58_022 as u64).saturating_mul(m as u64))
+			// Standard Error: 1_459
+			.saturating_add(Weight::from_ref_time(192_898 as u64).saturating_mul(p as u64))
 			.saturating_add(T::DbWeight::get().reads(5 as u64))
 			.saturating_add(T::DbWeight::get().writes(3 as u64))
 	}
@@ -199,10 +198,10 @@ impl<T: frame_system::Config> pallet_collective::WeightInfo for WeightInfo<T> {
 	// Storage: AllianceMotion ProposalOf (r:0 w:1)
 	/// The range of component `p` is `[1, 100]`.
 	fn disapprove_proposal(p: u32, ) -> Weight {
-		// Minimum execution time: 20_838 nanoseconds.
-		Weight::from_ref_time(24_287_938 as u64)
-			// Standard Error: 1_411
-			.saturating_add(Weight::from_ref_time(172_000 as u64).saturating_mul(p as u64))
+		// Minimum execution time: 23_077 nanoseconds.
+		Weight::from_ref_time(26_331_711 as u64)
+			// Standard Error: 1_620
+			.saturating_add(Weight::from_ref_time(176_129 as u64).saturating_mul(p as u64))
 			.saturating_add(T::DbWeight::get().reads(1 as u64))
 			.saturating_add(T::DbWeight::get().writes(3 as u64))
 	}
diff --git a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_timestamp.rs b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_timestamp.rs
index 8a4478c355a3995e541fb9c816bce9c7c7423ac7..b79e6891fcd202d2cebb808c2f222a909eceb36d 100644
--- a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_timestamp.rs
+++ b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_timestamp.rs
@@ -17,8 +17,8 @@
 //! Autogenerated weights for `pallet_timestamp`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2022-11-10, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
-//! HOSTNAME: `bm4`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
+//! DATE: 2022-12-05, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! HOSTNAME: `bm6`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
 //! EXECUTION: Some(Wasm), WASM-EXECUTION: Compiled, CHAIN: Some("collectives-polkadot-dev"), DB CACHE: 1024
 
 // Executed Command:
@@ -47,14 +47,15 @@ use sp_std::marker::PhantomData;
 pub struct WeightInfo<T>(PhantomData<T>);
 impl<T: frame_system::Config> pallet_timestamp::WeightInfo for WeightInfo<T> {
 	// Storage: Timestamp Now (r:1 w:1)
+	// Storage: Aura CurrentSlot (r:1 w:0)
 	fn set() -> Weight {
-		// Minimum execution time: 8_080 nanoseconds.
-		Weight::from_ref_time(8_314_000 as u64)
-			.saturating_add(T::DbWeight::get().reads(1 as u64))
+		// Minimum execution time: 10_004 nanoseconds.
+		Weight::from_ref_time(10_260_000 as u64)
+			.saturating_add(T::DbWeight::get().reads(2 as u64))
 			.saturating_add(T::DbWeight::get().writes(1 as u64))
 	}
 	fn on_finalize() -> Weight {
-		// Minimum execution time: 4_574 nanoseconds.
-		Weight::from_ref_time(4_704_000 as u64)
+		// Minimum execution time: 4_607 nanoseconds.
+		Weight::from_ref_time(4_799_000 as u64)
 	}
 }
diff --git a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_utility.rs b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_utility.rs
index f2eb033dd86c5d43a811dbb3c75e22098d011bdb..a84da7e373577f1e3bdc27ddbb51d3fd3a2bc9b4 100644
--- a/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_utility.rs
+++ b/cumulus/parachains/runtimes/collectives/collectives-polkadot/src/weights/pallet_utility.rs
@@ -17,8 +17,8 @@
 //! Autogenerated weights for `pallet_utility`
 //!
 //! THIS FILE WAS AUTO-GENERATED USING THE SUBSTRATE BENCHMARK CLI VERSION 4.0.0-dev
-//! DATE: 2022-11-10, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
-//! HOSTNAME: `bm4`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
+//! DATE: 2022-12-05, STEPS: `50`, REPEAT: 20, LOW RANGE: `[]`, HIGH RANGE: `[]`
+//! HOSTNAME: `bm6`, CPU: `Intel(R) Core(TM) i7-7700K CPU @ 4.20GHz`
 //! EXECUTION: Some(Wasm), WASM-EXECUTION: Compiled, CHAIN: Some("collectives-polkadot-dev"), DB CACHE: 1024
 
 // Executed Command:
@@ -48,31 +48,31 @@ pub struct WeightInfo<T>(PhantomData<T>);
 impl<T: frame_system::Config> pallet_utility::WeightInfo for WeightInfo<T> {
 	/// The range of component `c` is `[0, 1000]`.
 	fn batch(c: u32, ) -> Weight {
-		// Minimum execution time: 13_238 nanoseconds.
-		Weight::from_ref_time(15_145_125 as u64)
-			// Standard Error: 2_535
-			.saturating_add(Weight::from_ref_time(3_962_627 as u64).saturating_mul(c as u64))
+		// Minimum execution time: 13_403 nanoseconds.
+		Weight::from_ref_time(14_753_591 as u64)
+			// Standard Error: 1_994
+			.saturating_add(Weight::from_ref_time(4_081_884 as u64).saturating_mul(c as u64))
 	}
 	fn as_derivative() -> Weight {
-		// Minimum execution time: 6_888 nanoseconds.
-		Weight::from_ref_time(7_176_000 as u64)
+		// Minimum execution time: 7_028 nanoseconds.
+		Weight::from_ref_time(7_337_000 as u64)
 	}
 	/// The range of component `c` is `[0, 1000]`.
 	fn batch_all(c: u32, ) -> Weight {
-		// Minimum execution time: 13_696 nanoseconds.
-		Weight::from_ref_time(18_030_261 as u64)
-			// Standard Error: 2_621
-			.saturating_add(Weight::from_ref_time(4_096_976 as u64).saturating_mul(c as u64))
+		// Minimum execution time: 13_753 nanoseconds.
+		Weight::from_ref_time(17_175_869 as u64)
+			// Standard Error: 1_857
+			.saturating_add(Weight::from_ref_time(4_248_665 as u64).saturating_mul(c as u64))
 	}
 	fn dispatch_as() -> Weight {
-		// Minimum execution time: 15_188 nanoseconds.
-		Weight::from_ref_time(15_682_000 as u64)
+		// Minimum execution time: 15_834 nanoseconds.
+		Weight::from_ref_time(16_214_000 as u64)
 	}
 	/// The range of component `c` is `[0, 1000]`.
 	fn force_batch(c: u32, ) -> Weight {
-		// Minimum execution time: 13_264 nanoseconds.
-		Weight::from_ref_time(23_406_948 as u64)
-			// Standard Error: 2_736
-			.saturating_add(Weight::from_ref_time(3_949_653 as u64).saturating_mul(c as u64))
+		// Minimum execution time: 13_445 nanoseconds.
+		Weight::from_ref_time(14_662_383 as u64)
+			// Standard Error: 1_944
+			.saturating_add(Weight::from_ref_time(4_073_473 as u64).saturating_mul(c as u64))
 	}
 }